@@ -20,6 +20,7 @@
 import asyncio
 import functools
 import logging
+from copy import copy
 from pathlib import Path
 from warnings import filterwarnings
 
@@ -60,7 +61,7 @@ from telegram.ext import (
 )
 from telegram.warnings import PTBUserWarning
 from tests.auxil.build_messages import make_command_message
-from tests.auxil.files import PROJECT_ROOT_PATH
+from tests.auxil.files import SOURCE_ROOT_PATH
 from tests.auxil.pytest_classes import PytestBot, make_bot
 from tests.auxil.slots import mro_slots
 
@@ -307,8 +308,6 @@ class TestConversationHandler:
         )
 
     def test_repr_with_truncation(self):
-        from copy import copy
-
         states = copy(self.drinking_states)
         # there are exactly 3 drinking states. adding one more to make sure it's truncated
         states["extra_to_be_truncated"] = [CommandHandler("foo", self.start)]
@@ -725,7 +724,7 @@ class TestConversationHandler:
             assert recwarn[0].category is PTBUserWarning
             assert (
                 Path(recwarn[0].filename)
-                == PROJECT_ROOT_PATH / "telegram" / "ext" / "_handlers" / "conversationhandler.py"
+                == SOURCE_ROOT_PATH / "ext" / "_handlers" / "conversationhandler.py"
             ), "wrong stacklevel!"
             assert (
                 str(recwarn[0].message)
@@ -1105,11 +1104,7 @@ class TestConversationHandler:
                 assert warning.category is PTBUserWarning
                 assert (
                     Path(warning.filename)
-                    == PROJECT_ROOT_PATH
-                    / "telegram"
-                    / "ext"
-                    / "_handlers"
-                    / "conversationhandler.py"
+                    == SOURCE_ROOT_PATH / "ext" / "_handlers" / "conversationhandler.py"
                 ), "wrong stacklevel!"
             # now set app.job_queue back to it's original value
 
@@ -1428,8 +1423,7 @@ class TestConversationHandler:
             assert str(recwarn[0].message).startswith("ApplicationHandlerStop in TIMEOUT")
             assert recwarn[0].category is PTBUserWarning
             assert (
-                Path(recwarn[0].filename)
-                == PROJECT_ROOT_PATH / "telegram" / "ext" / "_jobqueue.py"
+                Path(recwarn[0].filename) == SOURCE_ROOT_PATH / "ext" / "_jobqueue.py"
             ), "wrong stacklevel!"
 
             await app.stop()
@@ -1438,7 +1432,7 @@ class TestConversationHandler:
         context = None
 
         async def start_callback(u, c):
-            nonlocal context, self
+            nonlocal context
             context = c
             return await self.start(u, c)
 
@@ -1459,7 +1453,6 @@ class TestConversationHandler:
         update = Update(update_id=0, message=message)
 
         async def timeout_callback(u, c):
-            nonlocal update, context
             assert u is update
             assert c is context
 
