@@ -28,6 +28,7 @@ from telegram import (
     VideoChatStarted,
 )
 from telegram._utils.datetime import UTC, to_timestamp
+from telegram.warnings import PTBDeprecationWarning
 from tests.auxil.slots import mro_slots
 
 
@@ -60,7 +61,7 @@ class TestVideoChatStartedWithoutRequest:
 
 
 class TestVideoChatEndedWithoutRequest:
-    duration = 100
+    duration = dtm.timedelta(seconds=100)
 
     def test_slot_behaviour(self):
         action = VideoChatEnded(8)
@@ -69,27 +70,50 @@ class TestVideoChatEndedWithoutRequest:
         assert len(mro_slots(action)) == len(set(mro_slots(action))), "duplicate slot"
 
     def test_de_json(self):
-        json_dict = {"duration": self.duration}
+        json_dict = {"duration": int(self.duration.total_seconds())}
         video_chat_ended = VideoChatEnded.de_json(json_dict, None)
         assert video_chat_ended.api_kwargs == {}
 
-        assert video_chat_ended.duration == self.duration
+        assert video_chat_ended._duration == self.duration
 
     def test_to_dict(self):
         video_chat_ended = VideoChatEnded(self.duration)
         video_chat_dict = video_chat_ended.to_dict()
 
         assert isinstance(video_chat_dict, dict)
-        assert video_chat_dict["duration"] == self.duration
+        assert video_chat_dict["duration"] == int(self.duration.total_seconds())
+
+    def test_time_period_properties(self, PTB_TIMEDELTA):
+        duration = VideoChatEnded(duration=self.duration).duration
+
+        if PTB_TIMEDELTA:
+            assert duration == self.duration
+            assert isinstance(duration, dtm.timedelta)
+        else:
+            assert duration == int(self.duration.total_seconds())
+            assert isinstance(duration, int)
+
+    def test_time_period_int_deprecated(self, recwarn, PTB_TIMEDELTA):
+        VideoChatEnded(self.duration).duration
+
+        if PTB_TIMEDELTA:
+            assert len(recwarn) == 0
+        else:
+            assert len(recwarn) == 1
+            assert "`duration` will be of type `datetime.timedelta`" in str(recwarn[0].message)
+            assert recwarn[0].category is PTBDeprecationWarning
 
     def test_equality(self):
         a = VideoChatEnded(100)
         b = VideoChatEnded(100)
+        x = VideoChatEnded(dtm.timedelta(seconds=100))
         c = VideoChatEnded(50)
         d = VideoChatStarted()
 
         assert a == b
         assert hash(a) == hash(b)
+        assert b == x
+        assert hash(b) == hash(x)
 
         assert a != c
         assert hash(a) != hash(c)
@@ -162,7 +186,6 @@ class TestVideoChatScheduledWithoutRequest:
         assert VideoChatScheduled(self.start_date).start_date == self.start_date
 
     def test_de_json(self, offline_bot):
-        assert VideoChatScheduled.de_json({}, bot=offline_bot) is None
 
         json_dict = {"start_date": to_timestamp(self.start_date)}
         video_chat_scheduled = VideoChatScheduled.de_json(json_dict, offline_bot)
